# Velcro [![Build Status](https://travis-ci.org/mwerner/velcro.svg?branch=master)](https://travis-ci.org/mwerner/velcro)

Velcro is meant to be a very straight-forward declarative way to automate the
setup of a new machine. It requires a `.dotfiles` directory to be cloned and
is very opinionated about the structure.

## Installation

Install the gem on your machine

    $ gem install velcro-strap

## Usage

Velcro uses a command line interface with the following commands:

### `strap`

Strap is the bread and butter of velcro. With one command you should be able to fully install a system as you're accustomed to using.

    $ velcro strap git@github.com:velcro/dotfiles.git

This will clone your dotfiles repo, load the `.velcrorc` file present in the cloned repo and process it on the current machine.

    Options:
      n, [--dryrun], [--no-dryrun]      Don't make any changes, just log output
      a, [--apps], [--no-apps]          Only install specified apps
      o, [--host], [--no-host]          Only run host specific configuration
      d, [--dotfiles], [--no-dotfiles]  Only clone the repo
      y, [--symlinks], [--no-symlinks]  Only symlink files
      c, [--scaffold], [--no-scaffold]  Only generate filesystem scaffolding
      s, [--settings], [--no-settings]  Only apply settings for your system

### `install`

You can install apps ad-hoc on your machine through velcro. This doesn't use any `.velcrorc`, the apps are just passed in at the command line

    $ velcro install zsh mysql

You can pass any number of app names to `install`. Velcro will look for matching names in `brew`, `cask` and `velcro` itself. You can look through the [installers directory] to find out more about velcro's installation method.

    Options:
      n, [--dryrun], [--no-dryrun]      Don't make any changes, just log output

### `symlink`

Velcro makes the assumption that you keep `*.symlink` files in your dotfiles directory. This command symlinks these files into your `$HOME` directory with a `.` prefix.

    $ velcro symlink

For example, if you had a file in your dotfiles repo such as `dotfiles/mysql/my.cnf.symlink` velcro would symlink that file to `~/.my.cnf`, right where it's supposed to be.

    Options:
      f, [--force]                      Overwrite existing symlinks in $HOME
      n, [--dryrun], [--no-dryrun]      Don't make any changes, just log output

### `status`

Running status will return various bits of information about the state of your machine. This is good to check what parts of the velcro process are done and which parts are not as you'd expect.

    $ velcro status

    Options:
      g, [--git], [--no-git]            Only report `git` information
      s, [--symlinks], [--no-symlinks]  Only show symlink mapping
      d, [--dotfiles], [--no-dotfiles]  Only check .dotfiles presence
      r, [--ruby], [--no-ruby]          Only report ruby version info

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/mwerner/velcro. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

